==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/complex/FormDisplayOrderCollection.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonPropertyOrder({
    "@odata.type", 
    "formDisplayOrderCollection"})
@JsonInclude(Include.NON_NULL)
public class FormDisplayOrderCollection implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("formDisplayOrderCollection")
    protected List<FormDisplayOrder> formDisplayOrderCollection;

    @JsonProperty("formDisplayOrderCollection@nextLink")
    protected String formDisplayOrderCollectionNextLink;

    protected FormDisplayOrderCollection() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.FormDisplayOrderCollection";
    }

    @Property(name="formDisplayOrderCollection")
    @JsonIgnore
    public CollectionPage<FormDisplayOrder> getFormDisplayOrderCollection() {
        return new CollectionPage<FormDisplayOrder>(contextPath, FormDisplayOrder.class, this.formDisplayOrderCollection, Optional.ofNullable(formDisplayOrderCollectionNextLink), SchemaInfo.INSTANCE, Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="formDisplayOrderCollection")
    @JsonIgnore
    public CollectionPage<FormDisplayOrder> getFormDisplayOrderCollection(HttpRequestOptions options) {
        return new CollectionPage<FormDisplayOrder>(contextPath, FormDisplayOrder.class, this.formDisplayOrderCollection, Optional.ofNullable(formDisplayOrderCollectionNextLink), SchemaInfo.INSTANCE, Collections.emptyList(), options);
    }

    public FormDisplayOrderCollection withUnmappedField(String name, String value) {
        FormDisplayOrderCollection _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private List<FormDisplayOrder> formDisplayOrderCollection;
        private String formDisplayOrderCollectionNextLink;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder formDisplayOrderCollection(List<FormDisplayOrder> formDisplayOrderCollection) {
            this.formDisplayOrderCollection = formDisplayOrderCollection;
            this.changedFields = changedFields.add("formDisplayOrderCollection");
            return this;
        }

        public Builder formDisplayOrderCollection(FormDisplayOrder... formDisplayOrderCollection) {
            return formDisplayOrderCollection(Arrays.asList(formDisplayOrderCollection));
        }

        public Builder formDisplayOrderCollectionNextLink(String formDisplayOrderCollectionNextLink) {
            this.formDisplayOrderCollectionNextLink = formDisplayOrderCollectionNextLink;
            this.changedFields = changedFields.add("formDisplayOrderCollection");
            return this;
        }

        public FormDisplayOrderCollection build() {
            FormDisplayOrderCollection _x = new FormDisplayOrderCollection();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.FormDisplayOrderCollection";
            _x.formDisplayOrderCollection = formDisplayOrderCollection;
            _x.formDisplayOrderCollectionNextLink = formDisplayOrderCollectionNextLink;
            return _x;
        }
    }

    private FormDisplayOrderCollection _copy() {
        FormDisplayOrderCollection _x = new FormDisplayOrderCollection();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.formDisplayOrderCollection = formDisplayOrderCollection;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("FormDisplayOrderCollection[");
        b.append("formDisplayOrderCollection=");
        b.append(this.formDisplayOrderCollection);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-microsoft-dynamics-0.1.45-sources.jar: microsoft/dynamics/crm/complex/FormDisplayOrderCollection.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "formDisplayOrderCollection"})
@JsonInclude(Include.NON_NULL)
public class FormDisplayOrderCollection implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("formDisplayOrderCollection")
    protected List<FormDisplayOrder> formDisplayOrderCollection;

    @JsonProperty("formDisplayOrderCollection@nextLink")
    protected String formDisplayOrderCollectionNextLink;

    protected FormDisplayOrderCollection() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.FormDisplayOrderCollection";
    }

    @Property(name="formDisplayOrderCollection")
    @JsonIgnore
    public CollectionPage<FormDisplayOrder> getFormDisplayOrderCollection() {
        return new CollectionPage<FormDisplayOrder>(contextPath, FormDisplayOrder.class, this.formDisplayOrderCollection, Optional.ofNullable(formDisplayOrderCollectionNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="formDisplayOrderCollection")
    @JsonIgnore
    public CollectionPage<FormDisplayOrder> getFormDisplayOrderCollection(HttpRequestOptions options) {
        return new CollectionPage<FormDisplayOrder>(contextPath, FormDisplayOrder.class, this.formDisplayOrderCollection, Optional.ofNullable(formDisplayOrderCollectionNextLink), Collections.emptyList(), options);
    }

    public FormDisplayOrderCollection withUnmappedField(String name, String value) {
        FormDisplayOrderCollection _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private List<FormDisplayOrder> formDisplayOrderCollection;
        private String formDisplayOrderCollectionNextLink;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder formDisplayOrderCollection(List<FormDisplayOrder> formDisplayOrderCollection) {
            this.formDisplayOrderCollection = formDisplayOrderCollection;
            this.changedFields = changedFields.add("formDisplayOrderCollection");
            return this;
        }

        public Builder formDisplayOrderCollection(FormDisplayOrder... formDisplayOrderCollection) {
            return formDisplayOrderCollection(Arrays.asList(formDisplayOrderCollection));
        }

        public Builder formDisplayOrderCollectionNextLink(String formDisplayOrderCollectionNextLink) {
            this.formDisplayOrderCollectionNextLink = formDisplayOrderCollectionNextLink;
            this.changedFields = changedFields.add("formDisplayOrderCollection");
            return this;
        }

        public FormDisplayOrderCollection build() {
            FormDisplayOrderCollection _x = new FormDisplayOrderCollection();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.FormDisplayOrderCollection";
            _x.formDisplayOrderCollection = formDisplayOrderCollection;
            _x.formDisplayOrderCollectionNextLink = formDisplayOrderCollectionNextLink;
            return _x;
        }
    }

    private FormDisplayOrderCollection _copy() {
        FormDisplayOrderCollection _x = new FormDisplayOrderCollection();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.formDisplayOrderCollection = formDisplayOrderCollection;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("FormDisplayOrderCollection[");
        b.append("formDisplayOrderCollection=");
        b.append(this.formDisplayOrderCollection);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
